@@ -1,3 +1,6 @@
+use crate::common::get_tag_attr;
+use crate::dummy::IdentityHandler;
+
 use super::TagHandler;
 use super::StructuredPrinter;
 
@@ -6,12 +9,20 @@ use markup5ever_rcdom::{Handle,NodeData};
 #[derive(Default)]
 pub struct AnchorHandler {
     start_pos: usize,
-    url: String
+    url: String,
+    emit_unchanged: bool,
 }
 
 impl TagHandler for AnchorHandler {
-
     fn handle(&mut self, tag: &Handle, printer: &mut StructuredPrinter) {
+        // Check for a `name` attribute. If it exists, we can't support this
+        // in markdown, so we must emit this tag unchanged.
+        if get_tag_attr(tag, "name").is_some() {
+            let mut identity = IdentityHandler::default();
+            identity.handle(tag, printer);
+            self.emit_unchanged = true;
+        }
+
         self.start_pos = printer.data.len();
 
         // try to extract a hyperlink
@@ -29,8 +40,11 @@ impl TagHandler for AnchorHandler {
     }
 
     fn after_handle(&mut self, printer: &mut StructuredPrinter) {
-        // add braces around already present text, put an url afterwards
-        printer.insert_str(self.start_pos, "[");
-        printer.append_str(&format!("]({})", self.url))
+        if !self.emit_unchanged {
+            // add braces around already present text, put an url afterwards
+            printer.insert_str(self.start_pos, "[");
+            printer.append_str(&format!("]({})", self.url))
+        }
     }
-}
\ No newline at end of file
+}
+
